@@ -35,6 +35,7 @@ from dbusmock.templates.networkmanager import (
     NMConnectivityState,
     NMState,
 )
+from packaging.version import Version
 
 tracemalloc.start(25)
 dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
@@ -171,8 +172,18 @@ class TestNetworkManager(dbusmock.DBusTestCase):
         self.assertRegex(res.stderr, b"No network.*nonexisting")
         self.assertRegex(self.read_device(), r"wlan0.*\sconnected\s+--")
 
+        # TODO: for connecting to password protected Wifi we need to implement secrets agent
+        # https://github.com/martinpitt/python-dbusmock/issues/216
+        out = subprocess.check_output(["nmcli", "--version"], universal_newlines=True)
+        m = re.search(r"([1-9.]+[0-9])", out)
+        assert m, "could not parse version from " + out
+        if Version(m.group(1)) >= Version("1.49.3"):
+            self.skipTest("https://github.com/martinpitt/python-dbusmock/issues/216")
+
         # connect to existing wifi with password
-        subprocess.check_call(["nmcli", "dev", "wifi", "connect", "AP_3", "password", "s3kr1t"])
+        subprocess.check_call(
+            ["timeout", "--signal=KILL", "5", "nmcli", "dev", "wifi", "connect", "AP_3", "password", "s3kr1t"]
+        )
         self.assertRegex(self.read_device(), r"wlan0.*\sconnected\s+AP_3")
 
         # connect to existing wifi without password
@@ -352,7 +363,7 @@ class TestNetworkManager(dbusmock.DBusTestCase):
 
         # Use the same settings, but this one will autoconnect.
         uuid2 = "22222222-2222-2222-2222-222222222222"
-        settings["connection"]["autoconnect"] = dbus.Boolean(True, variant_level=1)
+        settings["connection"]["autoconnect"] = dbus.Boolean(True)
         settings["connection"]["uuid"] = uuid2
 
         con2 = self.settings.AddConnection(settings)
